#[repr(C)]pub struct EmmcPartition {
pub id: EmmcPartitionId,
pub block_count: Uint64,
pub block_size: Uint32,
}Expand description
The wire type corresponding to EmmcPartition.
Fields
id: EmmcPartitionIdblock_count: Uint64block_size: Uint32Trait Implementations
Sourceimpl Clone for EmmcPartition
impl Clone for EmmcPartition
Sourcefn clone(&self) -> EmmcPartition
fn clone(&self) -> EmmcPartition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EmmcPartition
impl Constrained for EmmcPartition
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, EmmcPartition>,
_: <EmmcPartition as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, EmmcPartition>, _: <EmmcPartition as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for EmmcPartition
impl Debug for EmmcPartition
Sourceimpl<___D> Decode<___D> for EmmcPartitionwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EmmcPartitionwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EmmcPartition, ___E> for &'a EmmcPartitionwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EmmcPartition, ___E> for &'a EmmcPartitionwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmmcPartition>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmmcPartition>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EmmcPartition, ___E> for EmmcPartitionwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EmmcPartition, ___E> for EmmcPartitionwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmmcPartition>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmmcPartition>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<EmmcPartition, ___E> for EmmcPartition<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<EmmcPartitionId, ___E>,
T1: Encode<Uint64, ___E>,
T2: Encode<Uint32, ___E>,
impl<___E, T0, T1, T2> Encode<EmmcPartition, ___E> for EmmcPartition<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<EmmcPartitionId, ___E>,
T1: Encode<Uint64, ___E>,
T2: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmmcPartition>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmmcPartition>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EmmcPartition> for EmmcPartition
impl FromWire<EmmcPartition> for EmmcPartition
Sourcefn from_wire(wire: EmmcPartition) -> EmmcPartition
fn from_wire(wire: EmmcPartition) -> EmmcPartition
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<EmmcPartition> for EmmcPartition
impl FromWireRef<EmmcPartition> for EmmcPartition
Sourcefn from_wire_ref(wire: &EmmcPartition) -> EmmcPartition
fn from_wire_ref(wire: &EmmcPartition) -> EmmcPartition
Converts the given reference to this type.
Sourceimpl IntoNatural for EmmcPartition
impl IntoNatural for EmmcPartition
Sourcetype Natural = EmmcPartition
type Natural = EmmcPartition
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EmmcPartition
impl Wire for EmmcPartition
Sourcetype Narrowed<'de> = EmmcPartition
type Narrowed<'de> = EmmcPartition
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<EmmcPartition>)
fn zero_padding(out_: &mut MaybeUninit<EmmcPartition>)
Writes zeroes to the padding for this type, if any.